/*
 * playerwin.h
 * Thomas Nemeth, le 07.01.2002
 *
 *   Copyright (C) 1999  Thomas Nemeth
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef PLAYLISTWIN_H
#define PLAYLISTWIN_H


extern int playlist_display;

void display_playlist();
void display_list();

int previous();
int next();
int first();
int last();
int pgup();
int pgdn();
int enter();
int remove_entry();
int select_entry();
int sel_all();
int unsel_all();
int invert_sel();
int move_entry();
int get_cursor();
void set_cursor(int new_pos);

#endif

